pub struct SidebarSectionRow {
pub(super) display_name: TemplateChild<Label>,
notification_count: TemplateChild<Label>,
section: BoundObject<SidebarSection>,
section_binding: RefCell<Option<Binding>>,
is_expanded: Cell<bool>,
label: PhantomData<Option<String>>,
show_label_for_room_category: Cell<Option<RoomCategory>>,
}Fields
display_name: TemplateChild<Label>notification_count: TemplateChild<Label>section: BoundObject<SidebarSection>The section of this row.
section_binding: RefCell<Option<Binding>>is_expanded: Cell<bool>Whether this row is expanded.
label: PhantomData<Option<String>>The label to show for this row.
show_label_for_room_category: Cell<Option<RoomCategory>>The room category to show a label for during a drag-and-drop operation.
This will change the label according to the action that can be performed when dropping a room with the given category.
Implementations
Sourceimpl SidebarSectionRow
impl SidebarSectionRow
Sourcefn register_type()
fn register_type()
Registers the type only once.
Sourceimpl SidebarSectionRow
impl SidebarSectionRow
Sourcefn set_section(&self, section: Option<SidebarSection>)
fn set_section(&self, section: Option<SidebarSection>)
Set the section represented by this row.
Sourcefn set_is_expanded(&self, is_expanded: bool)
fn set_is_expanded(&self, is_expanded: bool)
Set whether this row is expanded.
Sourcefn update_highlight(&self)
fn update_highlight(&self)
Update how this row is highlighted according to the current state of rooms in this section.
Sourcefn update_expanded_accessibility_state(&self)
fn update_expanded_accessibility_state(&self)
Update the expanded state of this row for a11y.
Sourcepub(super) fn set_show_label_for_room_category(
&self,
category: Option<RoomCategory>,
)
pub(super) fn set_show_label_for_room_category( &self, category: Option<RoomCategory>, )
Set the room category to show the label for.